@@ -114,7 +114,7 @@ async_data_new (GeditGioDocumentSaver *gvsaver)
 {
 	AsyncData *async;
 	
-	async = g_new (AsyncData, 1);
+	async = g_slice_new (AsyncData);
 	async->saver = gvsaver;
 	async->buffer = NULL;
 	async->cancellable = g_object_ref (gvsaver->priv->cancellable);
@@ -128,7 +128,7 @@ async_data_free (AsyncData *async)
 {
 	g_object_unref (async->cancellable);
 	g_free (async->buffer);
-	g_free (async);
+	g_slice_free (AsyncData, async);
 }
 
 static void 
@@ -534,13 +534,13 @@ begin_write (AsyncData *async)
 	 */
 	gvsaver = async->saver;
 	gchar *buffer = gedit_document_saver_get_document_contents (GEDIT_DOCUMENT_SAVER (gvsaver), &len, &error);
-	
-	if (buffer)
+
+	if (buffer != NULL && len > 0)
 	{
 		/* Append new line to buffer */
 		buffer = append_new_line (gvsaver, buffer, &len, &error);
 	}
-	
+
 	if (!buffer)
 	{
 		async_failed (async, error);
@@ -594,15 +594,15 @@ mount_ready_callback (GFile        *file,
 static void
 recover_not_mounted (AsyncData *async)
 {
-	GeditDocumentSaver *saver;
+	GeditDocument *doc;
 	GMountOperation *mount_operation;
 	
-	gedit_debug_message (DEBUG_SAVER, "Try mount enclosing volume");
-	
+	gedit_debug (DEBUG_LOADER);
+
+	doc = gedit_document_saver_get_document (GEDIT_DOCUMENT_SAVER (async->saver));
+	mount_operation = _gedit_document_create_mount_operation (doc);
+
 	async->tried_mount = TRUE;
-	saver = GEDIT_DOCUMENT_SAVER (async->saver);
-	mount_operation = _gedit_document_create_mount_operation (saver->document);
-	
 	g_file_mount_enclosing_volume (async->saver->priv->gfile,
 				       G_MOUNT_MOUNT_NONE,
 				       mount_operation,
